InfiniteList class

Scrollable list

This widget renders CustomScrollView with 2 sliver list items

If direction is InfiniteListDirection.single it will render only forward sliver list item without center key

If direction is InfiniteListDirection.multi - both direction infinite list will be rendered

Inheritance

Constructors

InfiniteList({Key? key, required ItemBuilder<int> builder, ScrollController? controller, InfiniteListDirection direction = InfiniteListDirection.single, int? posChildCount, int? negChildCount, double anchor = 0.0, ScrollCacheExtent? scrollCacheExtent, Axis scrollDirection = Axis.vertical, ScrollPhysics? physics})

Properties

anchor → double
Proxy property for ScrollView.anchor
final
builder → ItemBuilder<int>
Builder callback. It should return InfiniteListItem instance.
final
controller → ScrollController?
Scroll controller
final
direction → InfiniteListDirection
List direction
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
negChildCount → int?
Max child count for negative list direction
final
physics → ScrollPhysics?
Proxy property for ScrollView.physics
final
posChildCount → int?
Max child count for positive direction list
final
reverse → bool
Proxy property for ScrollView.reverse
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollCacheExtent → ScrollCacheExtent?
Proxy property for RenderViewportBase.scrollCacheExtent
final
scrollDirection → Axis
Scroll direction
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited